(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('@clappr/core'), require('mpegts.js')) :
  typeof define === 'function' && define.amd ? define(['@clappr/core', 'mpegts.js'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.MpegtsJSPlayback = factory(global.Clappr, global.mpegts));
}(this, (function (core, mpegts) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var mpegts__default = /*#__PURE__*/_interopDefaultLegacy(mpegts);

  const MIMETYPES = ['video/flv', 'video/x-flv'];
  const EXTENSION = 'flv';
  class MpegtsJSPlayback extends core.HTML5Video {
    get name() {
      return 'mpegts';
    }

    get supportedVersion() {
      // eslint-disable-next-line no-undef
      return {
        min: "0.4.18"
      };
    }

    get isHTML5Video() {
      return true;
    }

    get mpegts() {
      return this._player;
    }

    getPlaybackType() {
      return this._playbackType;
    }

    play() {
      !this._player && this._setup();
      super.play();
    }

    stop() {
      super.stop();

      this._destroy();
    }

    destroy() {
      this._destroy();

      super.destroy();
    } // skipping setup `setupSrc` on tag video


    _setupSrc() {}

    _setup() {
      this._destroy();

      const mediaDataSource = {
        type: EXTENSION,
        url: this.options.src
      };
      const mpegtsConfig = this.options.playback.mpegtsConfig || {};
      this._playbackType = mpegtsConfig.isLive ? core.Playback.LIVE : core.Playback.VOD;
      const enableLogging = mpegtsConfig.enableLogging || false;
      mpegts__default['default'].LoggingControl.enableAll = enableLogging;
      this._player = mpegts__default['default'].createPlayer(mediaDataSource, mpegtsConfig);

      this._player.on(mpegts__default['default'].Events.ERROR, this._onError.bind(this));

      this._player.attachMediaElement(this.el);

      this._player.load();
    }

    _onError(type, details, data) {
      if (this.options.playback.hlsFallback) {
        this.configure({
          source: this.options.playback.hlsFallback,
          mimeType: "video/hls"
        });
      } else {
        core.Log.error(`mpegts: ${type}: ${details}`, data);
        const formattedError = this.createError({
          code: data.code || type,
          description: data.msg || details,
          raw: data,
          level: core.PlayerError.Levels.FATAL
        });
        this.trigger(core.Events.PLAYBACK_ERROR, formattedError);
        this.stop();
      }
    }

    _destroy() {
      if (!this._player) {
        return;
      }

      this._player.destroy();

      delete this._player;
    }

  }

  MpegtsJSPlayback.canPlay = (resource, mimeType = '') => {
    const resourceParts = resource.split('?')[0].match(/.*\.(.*)$/) || [];
    const isFLV = resourceParts.length > 1 && resourceParts[1].toLowerCase() === EXTENSION || MIMETYPES.indexOf(mimeType) !== -1;
    return mpegts__default['default'].isSupported() && isFLV;
  }; // eslint-disable-next-line no-undef


  MpegtsJSPlayback.version = () => VERSION;

  return MpegtsJSPlayback;

})));
